@@ -17,6 +17,7 @@ from .models import Project, Pledge, Backer, Update, Reward, MailTemplate
 from .widgets import AdminImageWidget, TestMailWidget
 
 from .paypal.models import Preapproval, Payment
+from .app_settings import PAYMENT_PROVIDERS
 
 
 def export_as_csv(modeladmin, request, queryset):
@@ -150,7 +151,7 @@ class PledgeAdmin(admin.ModelAdmin):
         return '%s %s' % (pledge.amount, pledge.currency)
     amount_display.short_description = _('amount')
 
-    def formfield_for_foreignkey(self, db_field, request=None, **kwargs):
+    def formfield_for_foreignkey(self, db_field, request, **kwargs):
         field = super(PledgeAdmin, self).formfield_for_foreignkey(
             db_field, request, **kwargs)
 
@@ -177,7 +178,7 @@ class PledgeAdmin(admin.ModelAdmin):
         'amount_display',
         'reward',
         'status',
-        'manually',
+        'provider',
     )
 
     list_display_links = (
@@ -199,7 +200,7 @@ class PledgeAdmin(admin.ModelAdmin):
     list_filter = (
         'project',
         'status',
-        'manually',
+        'provider',
         PaypalFilter,
         RewardListFilter
     )
