@@ -2,11 +2,11 @@ from django.db import models
 from decimal import Decimal
 
 class CurrencyField(models.DecimalField):
+    """ A simple currency field that rounds to 0.05 decimal points """
     __metaclass__ = models.SubfieldBase
 
     def to_python(self, value):
         try:
-            # TODO 5 may be correct for Switzerland. What about other countries?
             return super(CurrencyField, self).to_python(value).quantize(Decimal("0.05"))
         except AttributeError:
             return None
