@@ -1,7 +1,9 @@
 
+from django.conf import settings
 from django.db import models
 from django.utils.html import conditional_escape
 from django.utils.safestring import mark_safe
+from django.utils.translation import ugettext_lazy as _
 
 
 # Not available in django 1.4 yet
@@ -32,4 +34,4 @@ def get_object_or_none(klass, *args, **kwargs):
     try:
         return queryset.get(*args, **kwargs)
     except (queryset.model.DoesNotExist, ValueError):
-        return None
+        return None
\ No newline at end of file
